=======
History
=======

0.1.0 (2017-12-20)
------------------

* First release on PyPI.

0.8.2 (2020-01-25)
------------------

* No significant changes in functionality.
* Incorporating changes to the SEAMM infrastructure, which simplify
  the code for plug-ins.
* Updating the Travis CI to handle incompatible changes in Travis, and
  to use Conda environments in all steps.
